@@ -178,7 +178,7 @@ extract_jpeg (const gchar          *uri,
 		return;
 	}
 
-	f = tracker_file_open (filename, "rb", FALSE);
+	f = tracker_file_open (filename);
 	g_free (filename);
 
 	if (!f) {
@@ -418,6 +418,10 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
 	}
 
+        if (xd->regions) {
+	        tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
+        }
+
 	if (id->keywords) {
 		tracker_keywords_parse (keywords, id->keywords);
 	}
